@@ -5,7 +5,7 @@ use Bubblegum::Syntax -types;
 
 with 'Bubblegum::Object::Role::Value';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 requires 'defined';
 requires 'grep';
@@ -19,7 +19,7 @@ requires 'tail';
 
 sub reduce {
     my $self = CORE::shift;
-    my $code = type_cref CORE::shift;
+    my $code = type_coderef CORE::shift;
     my $a    = [0 .. $#{$self}];
     my $acc  = $a->head;
     $a->tail->map(sub { $acc = $code->($acc, $_) });
@@ -28,7 +28,7 @@ sub reduce {
 
 sub zip {
     my $self  = CORE::shift;
-    my $other = type_aref CORE::shift;
+    my $other = type_arrayref CORE::shift;
     my $this  = $self->length < $other->length ? $other : $self;
     my $a     = [0 .. $#{$this}];
     return $this->keys->map(sub { [$self->get($_), $other->get($_)] });
